from django import forms
from django.contrib.auth.forms import UserCreationForm
from .models import Payment, Route, User, Transportasi

class RegisterForm(UserCreationForm):
    birthdate = forms.DateField(widget=forms.DateInput(attrs={'type': 'date'}))
    phone_number = forms.CharField(max_length=15)
    blog_url = forms.URLField(required=False)
    bio = forms.CharField(widget=forms.Textarea, required=False)
    lokasi_duduk = forms.ChoiceField(choices=[("Jendela", "Jendela"), ("Tengah", "Tengah"), ("Gang", "Gang")])
    nomor_rangka = forms.CharField(max_length=50)

    class Meta:
        model = User
        fields = ["username", "email", "password1", "password2", "birthdate", "phone_number", "blog_url", "bio"]

    def save(self, commit=True):
        user = super().save(commit=False)
        if commit:
            user.save()
            transportasi = Transportasi.objects.create(
                lokasi_duduk=self.cleaned_data['lokasi_duduk'],
                nomor_rangka=self.cleaned_data['nomor_rangka']
            )
            user.transportasi = transportasi
            user.save()
        return user
    
class BookingForm(forms.Form):
    route = forms.ModelChoiceField(queryset=Route.objects.all())
    seat_number = forms.CharField(max_length=10)
    payment_method = forms.ChoiceField(choices=[('transfer', 'Transfer'), ('qris', 'QRIS')])
    
class PaymentForm(forms.ModelForm):
    class Meta:
        model = Payment
        fields = ['ticket', 'payment_method']  

    def save(self, commit=True):
        payment = super().save(commit=False)
        payment.amount = payment.ticket.route.price  
        if commit:
            payment.save()
        return payment